@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	$Id: mhamain.pl,v 2.41 2002/06/21 22:30:12 ehood Exp $
+##	$Id: mhamain.pl,v 2.43 2002/06/27 04:56:41 ehood Exp $
 ##  Author:
 ##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
@@ -29,7 +29,7 @@ package mhonarc;
 
 require 5;
 
-$VERSION = "2.5.7";
+$VERSION = "2.5.8";
 $VINFO =<<EndOfInfo;
   MHonArc v$VERSION (Perl $] $^O)
   Copyright (C) 1995-2002  Earl Hood, mhonarc\@mhonarc.org
@@ -1041,8 +1041,11 @@ sub output_mail {
     if (!$nocustom) {
 	#&defineIndex2MsgId();
 
-	($template = $SSMARKUP) =~ s/$VarExp/&replace_li_var($1,$index)/geo;
-	print $msghandle $template;
+	$template = ($MSGPGSSMARKUP ne '') ? $MSGPGSSMARKUP : $SSMARKUP;
+	if ($template ne '') {
+	    $template =~ s/$VarExp/&replace_li_var($1,$index)/geo;
+	    print $msghandle $template;
+	}
 
 	# Output comments -- more informative, but can be used for
 	#		     error recovering.
