@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	$Id: mhinit.pl,v 2.32 2002/06/07 17:45:09 ehood Exp $
+##	$Id: mhinit.pl,v 2.35 2002/06/28 03:28:10 ehood Exp $
 ##  Author:
 ##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
@@ -274,150 +274,8 @@ $TIdxMinPg	= -1;	# Starting page of thread index for updating
 $IdxPageNum	= 0;	# Page to output if genidx
 $DBPathName	= '';	# Full pathname of database file
 
-##----------------------------------------------------------------------
-##	BEGIN readmail.pl variable settings
-##----------------------------------------------------------------------
-##	Default filters
-##
-%readmail::MIMEFilters = (
-    # Content-type			Filter
-    #-------------------------------------------------------------------
-    "application/ms-tnef",		"m2h_null::filter",
-    "application/octet-stream",		"m2h_external::filter",
-    "application/x-patch",		"m2h_text_plain::filter",
-    "message/delivery-status",  	"m2h_text_plain::filter",
-    "message/external-body",   		"m2h_msg_extbody::filter",
-    "message/partial",   		"m2h_text_plain::filter",
-    "text/enriched",    		"m2h_text_enriched::filter",
-    "text/html",			"m2h_text_html::filter",
-    "text/plain",			"m2h_text_plain::filter",
-    "text/richtext",    		"m2h_text_enriched::filter",
-    "text/setext",			"m2h_text_setext::filter",
-    "text/tab-separated-values",	"m2h_text_tsv::filter",
-    "text/x-html",			"m2h_text_html::filter",
-    "text/x-setext",    		"m2h_text_setext::filter",
-
-    "application/*",		 	"m2h_external::filter",
-    "audio/*",				"m2h_external::filter",
-    "chemical/*",  			"m2h_external::filter",
-    "image/*",  			"m2h_external::filter",
-    "model/*",  			"m2h_external::filter",
-    "text/*",   			"m2h_text_plain::filter",
-    "video/*",  			"m2h_external::filter",
-
-    "x-sun-attachment",			"m2h_text_plain::filter",
-);
-%readmail::MIMEFiltersSrc = (
-    # Content-type			Filter
-    #-------------------------------------------------------------------
-    "application/ms-tnef",		"mhnull.pl",
-    "application/octet-stream",		"mhexternal.pl",
-    "application/x-patch",		"mhtxtplain.pl",
-    "message/delivery-status",  	"mhtxtplain.pl",
-    "message/external-body",   		"mhmsgextbody.pl",
-    "message/partial",   		"mhtxtplain.pl",
-    "text/enriched",    		"mhtxtenrich.pl",
-    "text/html",			"mhtxthtml.pl",
-    "text/plain",			"mhtxtplain.pl",
-    "text/richtext",    		"mhtxtenrich.pl",
-    "text/setext",			"mhtxtsetext.pl",
-    "text/tab-separated-values",	"mhtxttsv.pl",
-    "text/x-html",			"mhtxthtml.pl",
-    "text/x-setext",    		"mhtxtsetext.pl",
-
-    "application/*",		 	"mhexternal.pl",
-    "audio/*",				"mhexternal.pl",
-    "chemical/*",  			"mhexternal.pl",
-    "image/*",  			"mhexternal.pl",
-    "model/*",  			"mhexternal.pl",
-    "text/*",   			"mhtxtplain.pl",
-    "video/*",  			"mhexternal.pl",
-
-    "x-sun-attachment",			"mhtxtplain.pl",
-);
-$IsDefault{'MIMEFILTERS'} = 1;
-
-##  Default filter arguments
-##
-%readmail::MIMEFiltersArgs = (
-    # Content-type			Arguments
-    #-------------------------------------------------------------------
-    'm2h_external::filter',		'inline',
-);
-$IsDefault{'MIMEARGS'} = 1;
-
-##  Charset filters
-##
-%readmail::MIMECharSetConverters = (
-    # Character set			Converter Function
-    #-------------------------------------------------------------------
-    "plain",     			"mhonarc::htmlize",
-    "us-ascii",   			"mhonarc::htmlize",
-    "iso-8859-1",   			"mhonarc::htmlize",
-    "iso-8859-2",   			"MHonArc::CharEnt::str2sgml",
-    "iso-8859-3",   			"MHonArc::CharEnt::str2sgml",
-    "iso-8859-4",   			"MHonArc::CharEnt::str2sgml",
-    "iso-8859-5",   			"MHonArc::CharEnt::str2sgml",
-    "iso-8859-6",   			"MHonArc::CharEnt::str2sgml",
-    "iso-8859-7",   			"MHonArc::CharEnt::str2sgml",
-    "iso-8859-8",   			"MHonArc::CharEnt::str2sgml",
-    "iso-8859-9",   			"MHonArc::CharEnt::str2sgml",
-    "iso-8859-10",   			"MHonArc::CharEnt::str2sgml",
-    "iso-8859-15",   			"MHonArc::CharEnt::str2sgml",
-    "iso-2022-jp",   			"iso_2022_jp::str2html",
-    "latin1",   			"mhonarc::htmlize",
-    "latin2",   			"MHonArc::CharEnt::str2sgml",
-    "latin3",   			"MHonArc::CharEnt::str2sgml",
-    "latin4",   			"MHonArc::CharEnt::str2sgml",
-    "latin5",   			"MHonArc::CharEnt::str2sgml",
-    "latin6",   			"MHonArc::CharEnt::str2sgml",
-    "latin9",   			"MHonArc::CharEnt::str2sgml",
-    "windows-1250",   			"MHonArc::CharEnt::str2sgml",
-    "windows-1252",   			"MHonArc::CharEnt::str2sgml",
-    "default",     			"-ignore-",
-);
-%readmail::MIMECharSetConvertersSrc = (
-    # Character set			Converter Function
-    #-------------------------------------------------------------------
-    "plain",     			undef,
-    "us-ascii",   			undef,
-    "iso-8859-1",   			undef,
-    "iso-8859-2",   			"MHonArc/CharEnt.pm",
-    "iso-8859-3",   			"MHonArc/CharEnt.pm",
-    "iso-8859-4",   			"MHonArc/CharEnt.pm",
-    "iso-8859-5",   			"MHonArc/CharEnt.pm",
-    "iso-8859-6",   			"MHonArc/CharEnt.pm",
-    "iso-8859-7",   			"MHonArc/CharEnt.pm",
-    "iso-8859-8",   			"MHonArc/CharEnt.pm",
-    "iso-8859-9",   			"MHonArc/CharEnt.pm",
-    "iso-8859-10",   			"MHonArc/CharEnt.pm",
-    "iso-8859-15",   			"MHonArc/CharEnt.pm",
-    "iso-2022-jp",   			"iso2022jp.pl",
-    "latin1",   			undef,
-    "latin2",   			"MHonArc/CharEnt.pm",
-    "latin3",   			"MHonArc/CharEnt.pm",
-    "latin4",   			"MHonArc/CharEnt.pm",
-    "latin5",   			"MHonArc/CharEnt.pm",
-    "latin6",   			"MHonArc/CharEnt.pm",
-    "latin9",   			"MHonArc/CharEnt.pm",
-    "windows-1250",   			"MHonArc/CharEnt.pm",
-    "windows-1252",   			"MHonArc/CharEnt.pm",
-    "default",     			undef,
-);
-$IsDefault{'CHARSETCONVERTERS'} = 1;
-
-##  Content-Transfer-Encoding decoders:
-##    readmail.pl has a default set, so we just use it.
-##
-$IsDefault{'MIMEDECODERS'} = 1;
-
-##  Content-Types to exclude:
-##    Nothing is excluded by default.
-$IsDefault{'MIMEEXCS'} = 1;
-
-##------------------------------------------------------------------------
-##	END readmail.pl variable settings
-##------------------------------------------------------------------------
+##  Initialize readmail variables
+mhinit_readmail_vars();
 
 ##  Variable to hold function for converting message header text.
 $MHeadCnvFunc	= "mhonarc::htmlize";
@@ -574,7 +432,10 @@ $IDXONLY	= 0;	# Flag if generating index to stdout
 $RMM		= 0;	# Flag if removing messages
 $SCAN		= 0;	# Flag if doing an archive scan
 
-$SSMARKUP	= '';	# Initial markup of all pages
+$MSGPGSSMARKUP	= '';	# Initial markup of message pages
+$IDXPGSSMARKUP	= '';	# Initial markup of index pages
+$TIDXPGSSMARKUP	= '';	# Initial markup of thread index pages
+$SSMARKUP	= '';	# (Default) initial markup of all pages
 
 $IDXLABEL	= '';	# Label for main index
 $LIBEG  	= '';	# List open template for main index
@@ -735,4 +596,154 @@ $X = "\034";	# Value separator (should equal $;)
 
 ##---------------------------------------------------------------------------##
 
+sub mhinit_readmail_vars {
+
+##----------------------------------------------------------------------
+##	Default filters
+##
+%readmail::MIMEFilters = (
+    # Content-type			Filter
+    #-------------------------------------------------------------------
+    "application/ms-tnef",		"m2h_null::filter",
+    "application/octet-stream",		"m2h_external::filter",
+    "application/x-patch",		"m2h_text_plain::filter",
+    "message/delivery-status",  	"m2h_text_plain::filter",
+    "message/external-body",   		"m2h_msg_extbody::filter",
+    "message/partial",   		"m2h_text_plain::filter",
+    "text/enriched",    		"m2h_text_enriched::filter",
+    "text/html",			"m2h_text_html::filter",
+    "text/plain",			"m2h_text_plain::filter",
+    "text/richtext",    		"m2h_text_enriched::filter",
+    "text/setext",			"m2h_text_setext::filter",
+    "text/tab-separated-values",	"m2h_text_tsv::filter",
+    "text/x-html",			"m2h_text_html::filter",
+    "text/x-setext",    		"m2h_text_setext::filter",
+
+    "application/*",		 	"m2h_external::filter",
+    "audio/*",				"m2h_external::filter",
+    "chemical/*",  			"m2h_external::filter",
+    "image/*",  			"m2h_external::filter",
+    "model/*",  			"m2h_external::filter",
+    "text/*",   			"m2h_text_plain::filter",
+    "video/*",  			"m2h_external::filter",
+
+    "x-sun-attachment",			"m2h_text_plain::filter",
+);
+%readmail::MIMEFiltersSrc = (
+    # Content-type			Filter
+    #-------------------------------------------------------------------
+    "application/ms-tnef",		"mhnull.pl",
+    "application/octet-stream",		"mhexternal.pl",
+    "application/x-patch",		"mhtxtplain.pl",
+    "message/delivery-status",  	"mhtxtplain.pl",
+    "message/external-body",   		"mhmsgextbody.pl",
+    "message/partial",   		"mhtxtplain.pl",
+    "text/enriched",    		"mhtxtenrich.pl",
+    "text/html",			"mhtxthtml.pl",
+    "text/plain",			"mhtxtplain.pl",
+    "text/richtext",    		"mhtxtenrich.pl",
+    "text/setext",			"mhtxtsetext.pl",
+    "text/tab-separated-values",	"mhtxttsv.pl",
+    "text/x-html",			"mhtxthtml.pl",
+    "text/x-setext",    		"mhtxtsetext.pl",
+
+    "application/*",		 	"mhexternal.pl",
+    "audio/*",				"mhexternal.pl",
+    "chemical/*",  			"mhexternal.pl",
+    "image/*",  			"mhexternal.pl",
+    "model/*",  			"mhexternal.pl",
+    "text/*",   			"mhtxtplain.pl",
+    "video/*",  			"mhexternal.pl",
+
+    "x-sun-attachment",			"mhtxtplain.pl",
+);
+$IsDefault{'MIMEFILTERS'} = 1;
+
+##  Default filter arguments
+##
+%readmail::MIMEFiltersArgs = (
+    # Content-type			Arguments
+    #-------------------------------------------------------------------
+    'm2h_external::filter',		'inline',
+);
+$IsDefault{'MIMEARGS'} = 1;
+
+##  Charset filters
+##
+%readmail::MIMECharSetConverters = (
+    # Character set			Converter Function
+    #-------------------------------------------------------------------
+    "plain",     			"mhonarc::htmlize",
+    "us-ascii",   			"mhonarc::htmlize",
+    "iso-8859-1",   			"mhonarc::htmlize",
+    "iso-8859-2",   			"MHonArc::CharEnt::str2sgml",
+    "iso-8859-3",   			"MHonArc::CharEnt::str2sgml",
+    "iso-8859-4",   			"MHonArc::CharEnt::str2sgml",
+    "iso-8859-5",   			"MHonArc::CharEnt::str2sgml",
+    "iso-8859-6",   			"MHonArc::CharEnt::str2sgml",
+    "iso-8859-7",   			"MHonArc::CharEnt::str2sgml",
+    "iso-8859-8",   			"MHonArc::CharEnt::str2sgml",
+    "iso-8859-9",   			"MHonArc::CharEnt::str2sgml",
+    "iso-8859-10",   			"MHonArc::CharEnt::str2sgml",
+    "iso-8859-15",   			"MHonArc::CharEnt::str2sgml",
+    "iso-2022-jp",   			"iso_2022_jp::str2html",
+    "latin1",   			"mhonarc::htmlize",
+    "latin2",   			"MHonArc::CharEnt::str2sgml",
+    "latin3",   			"MHonArc::CharEnt::str2sgml",
+    "latin4",   			"MHonArc::CharEnt::str2sgml",
+    "latin5",   			"MHonArc::CharEnt::str2sgml",
+    "latin6",   			"MHonArc::CharEnt::str2sgml",
+    "latin9",   			"MHonArc::CharEnt::str2sgml",
+    "windows-1250",   			"MHonArc::CharEnt::str2sgml",
+    "windows-1252",   			"MHonArc::CharEnt::str2sgml",
+    "default",     			"-ignore-",
+);
+%readmail::MIMECharSetConvertersSrc = (
+    # Character set			Converter Function
+    #-------------------------------------------------------------------
+    "plain",     			undef,
+    "us-ascii",   			undef,
+    "iso-8859-1",   			undef,
+    "iso-8859-2",   			"MHonArc/CharEnt.pm",
+    "iso-8859-3",   			"MHonArc/CharEnt.pm",
+    "iso-8859-4",   			"MHonArc/CharEnt.pm",
+    "iso-8859-5",   			"MHonArc/CharEnt.pm",
+    "iso-8859-6",   			"MHonArc/CharEnt.pm",
+    "iso-8859-7",   			"MHonArc/CharEnt.pm",
+    "iso-8859-8",   			"MHonArc/CharEnt.pm",
+    "iso-8859-9",   			"MHonArc/CharEnt.pm",
+    "iso-8859-10",   			"MHonArc/CharEnt.pm",
+    "iso-8859-15",   			"MHonArc/CharEnt.pm",
+    "iso-2022-jp",   			"iso2022jp.pl",
+    "latin1",   			undef,
+    "latin2",   			"MHonArc/CharEnt.pm",
+    "latin3",   			"MHonArc/CharEnt.pm",
+    "latin4",   			"MHonArc/CharEnt.pm",
+    "latin5",   			"MHonArc/CharEnt.pm",
+    "latin6",   			"MHonArc/CharEnt.pm",
+    "latin9",   			"MHonArc/CharEnt.pm",
+    "windows-1250",   			"MHonArc/CharEnt.pm",
+    "windows-1252",   			"MHonArc/CharEnt.pm",
+    "default",     			undef,
+);
+$IsDefault{'CHARSETCONVERTERS'} = 1;
+
+##  Content-Transfer-Encoding decoders:
+##    readmail.pl has a default set, so we just use it.
+$IsDefault{'MIMEDECODERS'} = 1;
+
+##  Content-Types to exclude:
+##    Nothing is excluded by default.
+$IsDefault{'MIMEEXCS'} = 1;
+
+##  Content-type multipart/alternative preferences
+##    Note: The variable is not a readmail package variable, but it
+##	    is used to set readmail package properties.
+@MIMEAltPrefs = ( );
+$IsDefault{'MIMEALTPREFS'} = 1;
+
+}
+
+##---------------------------------------------------------------------------##
+
 1;
